Module: Google::Cloud::Storage::Control
- Defined in:
- lib/google/cloud/storage/control.rb,
lib/google/cloud/storage/control/version.rb
Constant Summary collapse
- VERSION =
"1.0.0"
Class Method Summary collapse
-
.configure {|::Google::Cloud.configure.storage_control| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-storage-control library.
-
.storage_control(version: :v2, &block) ⇒ ::Object
Create a new client object for StorageControl.
Class Method Details
.configure {|::Google::Cloud.configure.storage_control| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-storage-control library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
107 108 109 110 111 |
# File 'lib/google/cloud/storage/control.rb', line 107 def self.configure yield ::Google::Cloud.configure.storage_control if block_given? ::Google::Cloud.configure.storage_control end |
.storage_control(version: :v2, &block) ⇒ ::Object
Create a new client object for StorageControl.
By default, this returns an instance of
Google::Cloud::Storage::Control::V2::StorageControl::Client
for a gRPC client for version V2 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the StorageControl service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
About StorageControl
StorageControl service includes selected control plane operations.
68 69 70 71 72 73 74 75 76 77 |
# File 'lib/google/cloud/storage/control.rb', line 68 def self.storage_control version: :v2, &block require "google/cloud/storage/control/#{version.to_s.downcase}" package_name = Google::Cloud::Storage::Control .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Storage::Control.const_get(package_name).const_get(:StorageControl) service_module.const_get(:Client).new(&block) end |